/**
 * 
 */
package org.gcube.portlets.user.td.widgetcommonevent.client.type;

/**
 * 
 * @author "Giancarlo Panichi" 
 * <a href="mailto:g.panichi@isti.cnr.it">g.panichi@isti.cnr.it</a> 
 *
 */
public enum ChangeTableRequestType {
	CHANGECOLUMNTYPE,
	ADDCOLUMN,
	DELETECOLUMN,
	SPLITCOLUMN,
	GROUPBY,
	TIMEAGGREGATION,
	MERGECOLUMN,
	CHANGEPOSITIONCOLUMNS,
	CHANGECOLUMNLABEL,
	COLUMNFILTER,
	CHANGETABLETYPE,
	DELETEROWS,
	CLONETABULARRESOURCE,
	DUPLICATES,
	NORMALIZE,
	DENORMALIZE,
	TEMPLATEAPPLY,
	COLUMNREPLACE,
	COLUMNREPLACEBYEXPRESSION,
	COLUMNREPLACEBATCH,
	ROLLBACK,
	EDITROW,
	SHARE,
	GEOSPATIALCREATECOORDINATES,
	DOWNSCALECSQUARE,
	TASKRESUME,
	TASKRESUBMIT,
	STATISTICALOPERATION;
}
